@@ -8,7 +8,6 @@ from typing import Any, Dict, Iterator, List, Optional, Type, Union, cast
 import dask.array as da
 import numpy as np
 from dask import delayed
-from vispy.color import Colormap
 
 from .io import ZarrLocation
 from .types import JSONDict
@@ -262,10 +261,18 @@ class Multiscales(Spec):
     def __init__(self, node: Node) -> None:
         super().__init__(node)
 
+        axes_values = {"t", "c", "z", "y", "x"}
         try:
             multiscales = self.lookup("multiscales", [])
-            version = multiscales[0].get("version", "0.1")
+            version = multiscales[0].get(
+                "version", "0.1"
+            )  # should this be matched with Format.version?
             datasets = multiscales[0]["datasets"]
+            # axes field was introduced in 0.3, before all data was 5d
+            axes = tuple(multiscales[0].get("axes", ["t", "c", "z", "y", "x"]))
+            if len(set(axes) - axes_values) > 0:
+                raise RuntimeError(f"Invalid axes names: {set(axes) - axes_values}")
+            node.metadata["axes"] = axes
             datasets = [d["path"] for d in datasets]
             self.datasets: List[str] = datasets
             LOGGER.info("datasets %s", datasets)
@@ -274,14 +281,13 @@ class Multiscales(Spec):
             return  # EARLY EXIT
 
         for resolution in self.datasets:
-            # data.shape is (t, c, z, y, x) by convention
             data: da.core.Array = self.array(resolution, version)
             chunk_sizes = [
                 str(c[0]) + (" (+ %s)" % c[-1] if c[-1] != c[0] else "")
                 for c in data.chunks
             ]
             LOGGER.info("resolution: %s", resolution)
-            LOGGER.info(" - shape (t, c, z, y, x) = %s", data.shape)
+            LOGGER.info(" - shape %s = %s", axes, data.shape)
             LOGGER.info(" - chunks =  %s", chunk_sizes)
             LOGGER.info(" - dtype = %s", data.dtype)
             node.data.append(data)
@@ -292,9 +298,8 @@ class Multiscales(Spec):
             node.add(child_zarr, visibility=False)
 
     def array(self, resolution: str, version: str) -> da.core.Array:
-        nested = version != "0.1"
         # data.shape is (t, c, z, y, x) by convention
-        return self.zarr.load(resolution, nested)
+        return self.zarr.load(resolution)
 
 
 class OMERO(Spec):
@@ -337,7 +342,7 @@ class OMERO(Spec):
                     # TODO: make this value an enumeration
                     if model == "greyscale":
                         rgb = [1, 1, 1]
-                    colormaps.append(Colormap([[0, 0, 0], rgb]))
+                    colormaps.append([[0, 0, 0], rgb])
 
                 label = ch.get("label", None)
                 if label is not None:
@@ -391,7 +396,7 @@ class Well(Spec):
         # stitch full-resolution images into a grid
         def get_field(tile_name: str) -> np.ndarray:
             """tile_name is 'row,col'"""
-            row, col = [int(n) for n in tile_name.split(",")]
+            row, col = (int(n) for n in tile_name.split(","))
             field_index = (column_count * row) + col
             path = f"{field_index}/{level}"
             LOGGER.debug(f"LOADING tile... {path}")
@@ -521,7 +526,7 @@ class Plate(Spec):
     def get_stitched_grid(self, level: int, tile_shape: tuple) -> da.core.Array:
         def get_tile(tile_name: str) -> np.ndarray:
             """tile_name is 'level,z,c,t,row,col'"""
-            row, col = [int(n) for n in tile_name.split(",")]
+            row, col = (int(n) for n in tile_name.split(","))
             path = self.get_tile_path(level, row, col)
             LOGGER.debug(f"LOADING tile... {path}")
 
